<?php

class E2W_Plugins_GetFiveStars_Widget_Admin {

	protected $slug = 'e2w-plugins-getfivestars-widget';
	protected $table = 'e2w_get5_widget';

	function __construct() {
		add_action( 'admin_menu', array( $this, 'options_page_menu' ) );
		$plugin_basename = plugin_basename( E2W_PLUGINS_GETFIVESTARS_WIDGET_FILE );
		add_filter( 'plugin_action_links_' . $plugin_basename, array( $this, 'settings_link' ) );
		$this->add_scripts();
	}

	protected function add_scripts() {
		global $pagenow;
		if ( 'options-general.php' === $pagenow && isset( $_GET[ 'page' ] ) && $this->slug === $_GET[ 'page' ] ) {
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		}
	}

	function admin_enqueue_scripts() {
		wp_enqueue_script( 'jquery-base64', plugins_url( 'js/jquery.base64.min.js', E2W_PLUGINS_GETFIVESTARS_WIDGET_FILE ), array( 'jquery' ) );
		wp_enqueue_script( 'e2w-plugins-getfivestars-widget-admin', plugins_url( 'js/main.js', E2W_PLUGINS_GETFIVESTARS_WIDGET_FILE ), array( 'jquery' ) );
	}

	function options_page_menu() {
		add_options_page( 'GatherUp Widget', 'GatherUp Widget', 'manage_options', $this->slug, array( $this, 'options_page' ) );
	}

	function options_page() {
		$insert_status = $this->insert();
		$this->delete();
		$shortcode_table = new E2W_Plugins_GetFiveStars_Widget_Shortcode_Table( $this->table );
		$shortcode_table->prepare_items();
		require_once E2W_PLUGINS_GETFIVESTARS_WIDGET_PATH . '/tpl/admin.html.php';
	}

	protected function insert() {
		if ( isset( $_POST[ 'e2w-widget' ] ) ) {
			$widget = $_POST[ 'e2w-widget' ];
			global $wpdb;
			$content = (base64_decode( $widget[ 'code' ], true )) ? base64_decode( $widget[ 'code' ] ) : $widget['code'];
			$hash = $this->extractHashAndHost( $content );
			if ( ! empty( $hash ) ) {
				$data = array(
					'hash' => $hash,
					'title' => esc_html( $widget[ 'title' ] )
				);
				return $wpdb->insert( "{$wpdb->prefix}{$this->table}", $data, array( '%s', '%s' ) ) === false ? 0 : 1;
			}
			return 0;
		}
		return -1;
	}

	protected function delete() {
		if ( isset( $_GET[ 'action' ] ) && 'delete' === $_GET[ 'action' ] ) {
			global $wpdb;
			$wpdb->delete( "{$wpdb->prefix}{$this->table}", array( 'id' => $_GET[ 'itemid' ] ), array( '%d' ) );
		}
	}

	function settings_link( $links ) {
		$settings_link = '<a href="' . admin_url( 'options-general.php?page=' . $this->slug ) . '">Settings</a>';
		array_push( $links, $settings_link );
		return $links;
	}

	protected function plugin_version() {
		$result = array();
		if ( preg_match( '/\/([^\/]+\/[^\/]+)$/', E2W_PLUGINS_GETFIVESTARS_WIDGET_FILE, $result ) ) {
			$plugin_local_path = $result[ 1 ];
			$plugin_info = get_site_transient( 'update_plugins' );
			return $plugin_info->checked[ $plugin_local_path ];
		}
		return null;
	}

    // extract hash and host
	protected function extractHashAndHost( $content ) {
		$result = array();
        $advanced = $this->checkAdvancedWidget($content);

        if ($advanced) {
            return serialize($advanced);
        }

		$check = stripslashes( $content );
		$pregMatch1 = preg_match( '/(https?:\/\/[^\/]+)\/(reviews|badge)\/([^\'"]+)/i', $check, $result )  ;

		if ( $pregMatch1 ) {
			if ( isset( $result[ 1 ] ) && isset( $result[ 3 ] ) ) {
			    $hash = $result [3];
                $checkHash = explode('/', $hash);
                if(count($checkHash) > 1) {
                    $hash = $checkHash[0];
                    $additionalId = $checkHash[1];
                }
                $data = array(
					'host' => $result [ 1 ],
					'hash' => $hash
                );
				// check for badge
				if( $result[ 2 ] === 'badge' ) {
					$data[ 'badge' ] = true;
				}
				if(!empty($additionalId)) {
				    $data['additional'] = $additionalId;
                }

				return serialize( $data );
			}
		} else {
		    $result2 = array();

		    $matchNewWidget = preg_match('/(((https)?:\/\/[^\/]+)\/(reviews\-mobile\.js\/(.*)\"))/i', $check, $result2);

		    if ($matchNewWidget) {
                if (isset($result2[0])) {
                    $data = array();
                    $hashAndHost = trim($result2[0], "\'\;\"");
                    $hashAndHost = substr($hashAndHost, strpos($hashAndHost,'://')+strlen('://'));


                    $hashArr    = explode('/', $hashAndHost);

                    $hashAndBusiness = explode('.', $hashArr[2]);
                    $hash = explode('?',$hashAndBusiness[1]);

                    $data['host']       = trim($hashArr[0], "/");
                    $data['hash']       = $hash[0];
                    $data['business']   = $hashAndBusiness[0];

                    $additionalIdResult  = array();

                    preg_match("/(?<=data\-additionalId\=\")(.*)(=?\")/i", $check, $additionalIdResult);

                    if (!empty($additionalIdResult) && (is_numeric($additionalIdResult[1]))) {
                        $data['additional'] = $additionalIdResult[1];
                    } elseif (isset($hash[1])) {
                        $hashExplode = explode('=',$hash[1]);
                        $data['additional'] = $hashExplode[1];
                    }

                    $badge = preg_match( '/(?<=data\-widgettype)(.*)(badge)(=?\")/i', $check, $badgeResult );

                    if ($badge) {
                        $data['badge'] = true;
                    }

                    #$data['businessId']
                    $data['new'] = true;

                    return serialize($data);
                }
            }

            $pregMatch2 =  preg_match( '/(\'http\:(.*))(?<=type\+\'\/).*?(=?\'\;)/i', $check, $result );
		    if($pregMatch2) {
                if ( isset( $result[ 0 ] )) {

                    $data = array();
                    $hashAndHost = trim($result[0], "\'\;");
                    $hashArr    = explode('/\'+type+\'/', $hashAndHost);
                    $data['host'] = $hashArr[0];

                    $hashExplodeArr = explode('.', $hashArr[1]);
                    $hash = explode('?',$hashExplodeArr[1]);

                    $data['hash'] = $hash[0];

                    $additionalIdResult  = array();

                    preg_match("/(?<=data\-additionalId\=\")(.*)(=?\")/i", $check, $additionalIdResult);

                    if (!empty($additionalIdResult) && (is_numeric($additionalIdResult[1]))) {
                        $data['additional'] = $additionalIdResult[1];
                    } elseif (isset($hash[1])) {
                        $hashExplode = explode('=',$hash[1]);
                        $data['additional'] = $hashExplode[1];
                    }

                    $badgeResult = array();
                    $badge = preg_match( '/(?<=\'data\-widgettype\'\,\s\')(badge)(=?\')/i', $check, $badgeResult );

                    if ($badge) {
                        $data['badge'] = true;
                    }

                    return serialize($data);
                }
            }
        }
		return '';
	}

	private function getMatch($test, $content) {
        $matches = [];
        preg_match($test, $content, $matches);

        return isset($matches[1]) ? $matches[1] : false;
    }

    private function checkAdvancedWidget($content) {
        $business = $this->getMatch('/data-bid="(.*?)"/', $content);

        if (!$business) {
            return false;
        }

        $params = [
            'business' => $business,
            'advanced' => true,
            'host' => '',
            'hash' => '',
        ];

        if($aid = $this->getMatch('/data-aid="(.*?)"/', $content)) {
            $params['additional'] = $aid;
        }

        if($url = $this->getMatch('/data-url="(.*?)"/', $content)) {
            $params['host'] = $url;
        }

        if($this->getMatch('/src="(.*?)badgeAdv.min.js"/', $content)
            || $this->getMatch('/src="(.*?)badge.min.js"/', $content)
        ) {
            $params['badge'] = true;
        }

        return $params;
    }
}
