<?php

class E2W_Plugins_GetFiveStars_Widget_Shortcode_Table extends E2W_Plugins_List_Table {

	private $table;

	function __construct( $table ) {
		$this->table = $table;
		parent::__construct( array(
			'singular' => __( 'GatherUp Widget' ),
			'plural' => __( 'GatherUp Widgets' ),
			'ajax' => false
		) );
	}

	function no_items() {
		_e( 'No items found!' );
	}

	function column_default( $item, $column_name ) {
		if ( isset( $item[ $column_name ] ) ) {
			return $item[ $column_name ];
		}
		return 'error';
	}

	function get_sortable_columns() {
		return array(
			'title' => array( 'title', false )
		);
	}

	function column_title( $item ) {
		$actions = array(
			'delete' => sprintf( '<a onclick="if(confirm(\'Are you sure you want to delete &quot;' . $item[ 'title' ] . '&quot;?\')){return true}else{return false}" href="?page=%s&action=%s&itemid=%s">Delete</a>', $_REQUEST[ 'page' ], 'delete', $item[ 'id' ] )
		);

		return sprintf( '%1$s %2$s', $item[ 'title' ], $this->row_actions( $actions ) );
	}

	function column_hash( $item ) {
		$id = trim( $item[ 'id' ] );
		$shortcode = '[gatherup_widget id="' . $id . '"]';

		$actions = array(
			'select' => '<a href="javascript:jQuery(\'#e2w-getfivestars-widget-shortcode-' . $id . '\').select()">Select</a>'
		);

		$row = '<textarea rows="3" cols=15 style="font-weight: bold" readonly id="e2w-getfivestars-widget-shortcode-' . $id . '">' . htmlspecialchars( $shortcode ) . '</textarea>';

		return sprintf( '%1$s %2$s', $row, $this->row_actions( $actions ) );
	}

	function column_badge( $item ) {
		$id = trim( $item[ 'id' ] );
		$data = @unserialize( $item[ 'hash' ] );
		$row = isset( $data[ 'badge' ] ) ? '<span style="color: green">Yes</span>' : '<span style="color: red">No</span>';

		return sprintf( '%1$s', $row);
	}

	function get_columns() {
		$columns = array(
			'cb' => '<input type="checkbox" />',
			'title' => 'Widget Title',
			'badge' => 'Badge',
			'hash' => 'Shortcode'
		);
		return $columns;
	}

	function get_bulk_actions() {
		$actions = array(
		);
		return $actions;
	}

	function column_cb( $item ) {
		return sprintf(
				'<input type="checkbox" name="e2w-get5-widget[]" value="%s" />', $item[ 'id' ]
		);
	}

	function prepare_items() {
		global $wpdb;

		$columns = $this->get_columns();
		$hidden = array();
		$sortable = $this->get_sortable_columns();
		$this->_column_headers = array( $columns, $hidden, $sortable );

		$per_page = 5;
		$current_page = $this->get_pagenum();

		$total_items = $wpdb->get_var(
				"SELECT COUNT(*) FROM {$wpdb->prefix}{$this->table}"
		);
		$limit = $this->get_limit( $per_page, $current_page );
		$order = $this->get_order();

		$this->found_data = $wpdb->get_results(
				"SELECT * FROM {$wpdb->prefix}{$this->table} "
				. "ORDER BY {$order} "
				. "LIMIT {$limit}"
				, ARRAY_A );

		$this->set_pagination_args( array(
			'total_items' => $total_items,
			'per_page' => $per_page
		) );
		$this->items = $this->found_data;
	}

	protected function get_limit( $per_page, $current_page ) {
		$per_page = intval( $per_page );
		return ((intval( $current_page ) - 1) * $per_page) . ',' . $per_page;
	}

	protected function get_order() {
		$orderby = ( ! empty( $_GET[ 'orderby' ] ) ) ? $_GET[ 'orderby' ] : '';
		$order_by_result = 'id';
		foreach ( $this->get_sortable_columns() as $key => $val ) {
			if ( $orderby === $key ) {
				$order_by_result = $key;
			}
		}
		$order = ( ! empty( $_GET[ 'order' ] ) ) ? $_GET[ 'order' ] : 'desc';
		$order_direction = in_array( $order, array( 'asc', 'desc' ) ) ? $order : 'desc';
		return "{$order_by_result} {$order_direction}";
	}

}
